==> allura-1.8.0.tar.gz: allura-1.8.0/Allura/allura/tests/unit/test_discuss.py <==
#       Licensed to the Apache Software Foundation (ASF) under one
#       or more contributor license agreements.  See the NOTICE file
#       distributed with this work for additional information
#       regarding copyright ownership.  The ASF licenses this file
#       to you under the Apache License, Version 2.0 (the
#       "License"); you may not use this file except in compliance
#       with the License.  You may obtain a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#       Unless required by applicable law or agreed to in writing,
#       software distributed under the License is distributed on an
#       "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
#       KIND, either express or implied.  See the License for the
#       specific language governing permissions and limitations
#       under the License.

from nose.tools import assert_false, assert_true

from allura import model as M
from allura.tests.unit import WithDatabase
from allura.tests.unit.patches import fake_app_patch


class TestThread(WithDatabase):
    patches = [fake_app_patch]

    def test_should_update_index(self):
        p = M.Thread()
        assert_false(p.should_update_index({}, {}))
        old = {'num_views': 1}
        new = {'num_views': 2}
        assert_false(p.should_update_index(old, new))
        old = {'num_views': 1, 'a': 1}
        new = {'num_views': 2, 'a': 1}
        assert_false(p.should_update_index(old, new))
        old = {'num_views': 1, 'a': 1}
        new = {'num_views': 2, 'a': 2}
        assert_true(p.should_update_index(old, new))

==> allura-1.18.0.tar.gz: allura-1.18.0/Allura/allura/tests/unit/test_discuss.py <==
#       Licensed to the Apache Software Foundation (ASF) under one
#       or more contributor license agreements.  See the NOTICE file
#       distributed with this work for additional information
#       regarding copyright ownership.  The ASF licenses this file
#       to you under the Apache License, Version 2.0 (the
#       "License"); you may not use this file except in compliance
#       with the License.  You may obtain a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#       Unless required by applicable law or agreed to in writing,
#       software distributed under the License is distributed on an
#       "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
#       KIND, either express or implied.  See the License for the
#       specific language governing permissions and limitations
#       under the License.

from allura import model as M
from allura.tests.unit import WithDatabase
from allura.tests.unit.patches import fake_app_patch


class TestThread(WithDatabase):
    patches = [fake_app_patch]

    def test_should_update_index(self):
        p = M.Thread()
        assert not p.should_update_index({}, {})
        old = {'num_views': 1}
        new = {'num_views': 2}
        assert not p.should_update_index(old, new)
        old = {'num_views': 1, 'a': 1}
        new = {'num_views': 2, 'a': 1}
        assert not p.should_update_index(old, new)
        old = {'num_views': 1, 'a': 1}
        new = {'num_views': 2, 'a': 2}
        assert p.should_update_index(old, new)
